@@ -12,5 +12,5 @@ void initgame();
 /* returns 1 to play again */
 int startgame();
 
-const char *get_wonlost_stats(const char *opponent);
-void	    upd_wonlost_stats(const char *opponent, int won);
+const char *get_wonlost_stats(const char *me, const char *opponent);
+void	    upd_wonlost_stats(const char *me, const char *opponent, int won);
