@@ -3,6 +3,8 @@ int startup_menu(int i, int x, int y);
 int select_2p_tty(int x, int y);
 int menu_checkinvit(int x, int y);
 
+int netplay_menu(int x, int y);
+
 #ifdef menu_h
 void options_menu(const char **items, int n, menuhandler f, int x, int y);
 #endif
@@ -20,4 +22,6 @@ int select_blockstyle(int k);
 /* Outer functions */
 int startupmenu(int i);
 int gamemenu();
+int netplaymenu();
+void hiscorelist();
 void optionsmenu();
