@@ -1,5 +1,6 @@
 #include <ctype.h>
 #include "textgfx.h"
+#include "../lang.h"
 
 void putch_ascii(int ch)
 {
@@ -54,7 +55,8 @@ void printstr_acs(const char *str, int n)
 	}
 }
 
-int isprintable(char c)
+int isprintable(int c)
 {
-	return (c < 0 || c >= ' ' && c != 0x7F);
+	return c >= ' ' && c < 0x7F ||
+	       lang & LATIN1 && (unsigned char) c >= 0xA0;
 }
